@@ -11,18 +11,19 @@
 # it to be compatible with degPlotCluster
 .process <- function(table, time, color){
     stopifnot(c("genes", "sample", time, "cluster", "expression")  %in% names(table))
-    
-    if (!is.null(color))
+
+        if (!is.null(color))
         stopifnot(color  %in% names(table))
     if (is.null(color)){
-        tb <- group_by(table, !!sym("genes"),
-                       !!sym(time), !!sym("cluster")) 
+        grouped <- group_by(table, genes,
+                            !!sym(time), cluster)
     }else{
-        tb <- group_by(table, !!sym("genes"),
-                       !!sym(time), !!sym("cluster"), !!sym(color)) 
+        grouped <- group_by(table, genes,
+                            !!sym(time), cluster, !!sym(color))
     }
     
-    summarise(tb, expression=mean(expression)) %>% 
+    grouped %>% 
+        summarise(expression=mean(expression)) %>% 
         group_by(!!sym("genes")) %>% 
         mutate(value = scale(expression)) %>% 
         ungroup()
@@ -332,7 +333,6 @@ degPlotCluster <- function(table, time, color = NULL,
 }
 
 .benckmark_cutoff <- function(tree, counts, minc = 15){
-    # browser()
     series <- unique(round(tree$height, digits = 3))
     series <- sort(series[2:length(series)])
     list_clusters <- lapply(series, function(s) {
@@ -462,7 +462,7 @@ degPlotCluster <- function(table, time, color = NULL,
     if (!summarize %in% names(metadata))
         metadata[,summarize] = paste0(metadata[,col_transformed], metadata[,time])
 
-    metadata_groups = metadata %>% dplyr::distinct_(summarize, .keep_all = TRUE)
+    metadata_groups = metadata %>% dplyr::distinct(!!sym(summarize), .keep_all = TRUE)
     rownames(metadata_groups) = metadata_groups[,summarize]
     return(metadata_groups)
 }
@@ -780,7 +780,6 @@ degPCA <- function(counts, metadata = NULL, condition=NULL,
                    pc1 = "PC1", pc2 = "PC2",
                    name = NULL, shape = NULL,
                    data = FALSE){
-    # browser()
     pc <- .pca_loadings(counts)
     # error if pc1/2 are not in columns of pc
     idx1 <- which(names(pc[["percentVar"]]) == pc1)
@@ -1053,7 +1052,7 @@ degPatterns = function(ma, metadata, minc=15, summarize="merge",
     
     colnames(norm_sign) <- colnames(counts_group)
     metadata_groups <- metadata %>%
-        dplyr::distinct_(summarize, .keep_all = TRUE)
+        dplyr::distinct(!!sym(summarize), .keep_all = TRUE)
     rownames(metadata_groups) = metadata_groups[,summarize]
     norm_sign <- norm_sign[, row.names(metadata_groups), drop = FALSE]
     if (nrow(ma) == 1){
