@@ -80,7 +80,7 @@
     colnames(all_cor_p) <- colnames(all_covariates)
     
     effects.significantcovars <- all_cor_vals
-    effects.significantcovars[all_cor_p > max_fdr] <- 0
+    #effects.significantcovars[all_cor_p > max_fdr] <- 0
     effects.significantcovars <- colSums(abs(effects.significantcovars) * replicate(dim(effects.significantcovars)[2L], weights / sum(weights)))
     effects.significantcovars <- effects.significantcovars[order(abs(effects.significantcovars), decreasing = TRUE)]
 
@@ -184,11 +184,10 @@
         pc_sig <- .model(data, method)
         pc_sig[["PC"]] = pc
         pc_sig %>% filter(p.value < 0.05)
-    }) %>% bind_rows() %>% 
-        filter(!grepl("Intercept", !!!sym("term")))
-    
+    }) %>% bind_rows()
+
     if (nrow(significants) == 0)
-        return(data.frame(estimate=0, p.value=0, PC="", term=""))
+        return(data.frame(estimate=0, p.value=0, PC="1", term="noterm"))
     significants[,c("estimate", "p.value", "PC", "term")]
 }
 
@@ -258,7 +257,10 @@
 #'   of the covariates effect on the PCs. For that, this function
 #'   uses `lm` to regress the data and uses the p-value calculated by
 #'   each variable in the model to define significance (pvalue < 0.05).
-#'   `lm` or `lasso` can be used here.
+#'   `lm` or `lasso` can be used here. Variables with a black stroke
+#'   are significant after this step. Variables with grey stroke 
+#'   are significant at the first pass considering p.value < 0.05
+#'   for the correlation analysis.
 #' @references 
 #' Daily, K. et al.  Molecular, phenotypic, and sample-associated data to describe pluripotent stem cell lines and derivatives. Sci Data 4, 170030 (2017).
 #'  
@@ -393,7 +395,8 @@ degCovariates <- function(counts, metadata,
               by = c("compare" = "PC", 
                      "covar" = "term")) %>% 
         left_join(pc_pct, by = c("compare" = "pc")) %>% 
-        unite(col = "compare", !!!sym("compare"), !!!sym("pct"), sep = " ")
+        unite(col = "compare", !!sym("compare"), !!sym("pct"),
+              sep = " ")
     ma_plot[["r"]][is.na(ma_plot[["p.value"]])] = NA
     if (legacy){
         if (addCovDen){
@@ -439,7 +442,7 @@ degCovariates <- function(counts, metadata,
         
         ma_plot[["covar"]] <- factor(ma_plot[["covar"]],
                                 levels = hc$labels[hc$order])
-        # browser()
+
         tile <- ggplot(ma_plot, aes_(x = ~covar,y = ~compare,
                              size = ~effect_size,
                              color = ~r,
@@ -448,6 +451,8 @@ degCovariates <- function(counts, metadata,
             geom_point() +
             geom_point(data = filter(ma_plot, !is.na(fdr)),
                        stroke = 1, color="black") +
+            geom_point(data = filter(ma_plot, pvalue<0.05),
+                       stroke = 1, color="grey60") +
             theme_minimal() +
             scale_shape_manual(values = c(22, 21)) + 
             scale_size_continuous(name = "importance",
@@ -521,6 +526,8 @@ degClean <- function(ma){
 #' @param fdr numeric value to use as cutoff to determine
 #'   the minimum fdr to consider significant correlations
 #'   between pcs and covariates.
+#' @param use_pval boolean to indicate to use p-value instead of FDR to
+#'   hide non-significant correlation.
 #' @param ... Parameters to pass to [ComplexHeatmap::Heatmap()].
 #'
 #' @return: list:
@@ -536,21 +543,26 @@ degClean <- function(ma){
 #'   colData(humanGender)[idx,], design=~group)
 #' cor <- degCorCov(colData(dse))
 #' @export
-degCorCov <- function(metadata, fdr=0.05, ...){
+degCorCov <- function(metadata, fdr=0.05, use_pval = FALSE, ...){
     clean <- degClean(metadata) %>%
         mutate_all(as.numeric)
     cor <- .calccompletecorandplot(clean,
-                                      clean,
-                                      "kendall",
-                                      "",
-                                      weights = 1L)
-    
+                                   clean,
+                                   "kendall",
+                                   "",
+                                   max_fdr = fdr,
+                                   weights = 1L)
+    #browser()
+    if (use_pval){
+        cor[["mat"]]['fdr'] <- cor[["mat"]]['pvalue']
+    }
     corMat <- cor[["mat"]][, c("r", "compare", "covar")] %>%
         spread(!!sym("compare"), !!sym("r")) %>% remove_rownames() %>%
         column_to_rownames("covar")
     fdrMat <- cor[["mat"]][, c("fdr", "compare", "covar")] %>%
         spread(compare, fdr) %>% remove_rownames() %>%
         column_to_rownames("covar")
+
     corMat[fdrMat > fdr] <- 0
     # corMat[fdrMat > 0.05] <- NA
     if (sum(!is.na(corMat)) > 2) {
